==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/hotkey/translations/hotkey_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Keisti nuorodą</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Paspauskite klavišų kombinaciją, kurią norite priskirti</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="30"/>
        <source>Global Hotkey Plugin</source>
        <translation>Global Hotkey klavišų įskiepis</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="50"/>
        <source>About Global Hotkey Plugin</source>
        <translation>Apie Global Hotkey įskiepį</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Qmmp Global Hotkey įskiepis</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>This plugin adds support for multimedia keys or global key combinations</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Play</source>
        <translation>Groti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Pause</source>
        <translation>Pauzė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Play/Pause</source>
        <translation>Groti/Pauzė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Next</source>
        <translation>Sekantis takelis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Previous</source>
        <translation>Ankstesnis takelis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Show/Hide</source>
        <translation>Rodyti/Slėpti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Volume +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="50"/>
        <source>Volume -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>Global Hotkey nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>Veiksmas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>Nuoroda</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>Ištrinti</translation>
    </message>
</context>
</TS>

==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/General/hotkey/translations/hotkey_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Keisti nuorodą</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>Paspauskite klavišų kombinaciją, kurią norite priskirti</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="30"/>
        <source>Global Hotkey Plugin</source>
        <translation>Global Hotkey klavišų įskiepis</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="50"/>
        <source>About Global Hotkey Plugin</source>
        <translation>Apie Global Hotkey įskiepį</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Qmmp Global Hotkey įskiepis</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>This plugin adds support for multimedia keys or global key combinations</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Play</source>
        <translation>Groti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Pause</source>
        <translation>Pauzė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Play/Pause</source>
        <translation>Groti/Pauzė</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Next</source>
        <translation>Sekantis takelis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Previous</source>
        <translation>Ankstesnis takelis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Show/Hide</source>
        <translation>Rodyti/Slėpti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Volume +</source>
        <translation>Garsas +</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="50"/>
        <source>Volume -</source>
        <translation>Garsas -</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>Global Hotkey nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>Veiksmas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>Nuoroda</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>Ištrinti</translation>
    </message>
</context>
</TS>
